__version__ = '0.8a3'

import unittest
import xml.dom

import cssutils.css

import test_cssrule


class CSSCharsetRuleTestCase(test_cssrule.CSSRuleTestCase):

    def setUp(self):
        self.r = cssutils.css.CSSCharsetRule()
        self.rRO = cssutils.css.CSSCharsetRule(readonly=True)
        self.r_type = cssutils.css.CSSCharsetRule.CHARSET_RULE


    def test_init(self):
        super(CSSCharsetRuleTestCase, self).test_init()
        # +
        r = cssutils.css.CSSCharsetRule(u'utf-8')
        self.assertEqual(u'utf-8', r.encoding)
        self.assertEqual(u'@charset "utf-8";', r.cssText)

                
    def test_readonly(self):
        super(CSSCharsetRuleTestCase, self).test_readonly()
        # +
        r = cssutils.css.CSSCharsetRule(u'utf-8', readonly=True)
        self.r.encoding = u'utf-8'
        self.assertRaises(xml.dom.NoModificationAllowedErr,
                          r._setEncoding, u'x')
        self.r.encoding = u'utf-8'


    def test_encoding(self):
        self.r.encoding = u'UTF-8'
        self.assertEqual(u'UTF-8', self.r.encoding)
        self.r.encoding = u'iso-8859-1'
        self.assertEqual(u'iso-8859-1', self.r.encoding)
        # error        
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setEncoding, u'FALSE ENC')


    def test_cssText(self):
        self.r.cssText = u'@charset    "utf-8"  ;  ' 
        self.assertEqual(u'utf-8', self.r.encoding)
        self.assertEqual(u'@charset "utf-8";', self.r.cssText)

        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, u'@charset "utf-8;')

        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, u'@charset "utf-8"')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, u'@charset { utf-8 }')

        # has to start with @!
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u' @charset "utf-8";')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'@other "utf-8";')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'other { color: red;}')


if __name__ == '__main__':
    unittest.main() 