__version__ = '0.8a2'

import unittest
import xml.dom

import cssutils.css
import cssutils.stylesheets

import test_cssrule


class CSSImportRuleTestCase(test_cssrule.CSSRuleTestCase):

    def setUp(self):
        self.r = cssutils.css.CSSImportRule()
        self.rRO = cssutils.css.CSSImportRule(readonly=True)
        self.r_type = cssutils.css.CSSImportRule.IMPORT_RULE

    def test_init(self):
        super(CSSImportRuleTestCase, self).test_init()
        # +
        r = cssutils.css.CSSImportRule(u'css/test.css', u'tv, print')
        self.assertEqual(cssutils.stylesheets.MediaList, type(r.media))
        self.assertEqual(u'css/test.css', r.href)
        self.assertEqual(None, r.styleSheet)
        self.assertEqual(u'@import url(css/test.css) tv, print;', r.cssText)

        r = cssutils.css.CSSImportRule(href=u'test2.css')
        self.assertEqual(cssutils.stylesheets.MediaList, type(r.media))
        self.assertEqual(u'test2.css', r.href)
        self.assertEqual(u'@import url(test2.css);', r.cssText)

        r = cssutils.css.CSSImportRule(mediaText=u'tv, screen')
        self.assertEqual(cssutils.stylesheets.MediaList, type(r.media))
        self.assertEqual(u'', r.href)
        self.assertEqual(u'', r.cssText)

    def test_emptyMediaList(self):
        i = cssutils.css.CSSImportRule(u'css/test.css', u'')
        self.assertEqual(u'@import url(css/test.css);', i.cssText)

        i.media.appendMedium('print')        
        self.assertEqual(u'@import url(css/test.css) print;', i.cssText)

        i.media.appendMedium('tv')        
        self.assertEqual(u'@import url(css/test.css) print, tv;', i.cssText)

    def test_cssText(self):
        self.r.cssText = u'@import url(css/test.css) tv, print;' 
        self.assertEqual(u'css/test.css', self.r.href)
        self.assertEqual(u'@import url(css/test.css) tv, print;', self.r.cssText)

        self.assertRaises(xml.dom.SyntaxErr, self.r._setCssText, u'@import url("x);')
        self.assertRaises(xml.dom.SyntaxErr, self.r._setCssText, u'@import all url;')
        self.assertRaises(xml.dom.SyntaxErr, self.r._setCssText, u'@import url(x")')
        
        self.assertRaises(xml.dom.InvalidModificationErr, self.r._setCssText, u'@other "utf-8";')
        self.assertRaises(xml.dom.InvalidModificationErr, self.r._setCssText, u'other { color: red;}')


if __name__ == '__main__':
    unittest.main() 